
Type.registerNamespace('FullSize');


FullSize.FullSizeCommandEventId =
{
    PreviousSlide: 'PreviousSlide',
    NextSlide: 'NextSlide',
    Refresh: 'Refresh',
    CheckboxToggle: 'CheckboxToggle',
    PlayFromSlide: 'PlayFromSlide'
}

FullSize.StatusChangeEventId =
{
    SlideChanged: 'SlideChanged'
}

FullSize.FullSizeHelper = function FullSize_FullSizeHelper() {
    this._fullSizeCurrentSlideNumber = -1;
    this._commandEvents = new Sys.EventHandlerList();
    this._statusChangeEvents = new Sys.EventHandlerList();
}
FullSize.FullSizeHelper.prototype = {

    get_mainPlayer: function FullSize_FullSizeHelper$get_mainPlayer() {
        if (SfKernel.Util.IsNullOrUndefined(window.opener)) {
            throw Error.invalidOperation('Window Opener Unavailable');
        }
        return window.opener.mPlayer;
    },

    get_manifest: function FullSize_FullSizeHelper$get_manifest() {
        if (SfKernel.Util.IsNullOrUndefined(window.opener)) {
            throw Error.invalidOperation('Opener Unavailable');
        }
        return window.opener.Manifest;
    },

    get_layoutOptions: function FullSize_FullSizeHelper$get_layoutOptions() {
        if (SfKernel.Util.IsNullOrUndefined(window.opener)) {
            throw Error.invalidOperation('Opener Unavailable');
        }
        return window.opener.LayoutOptions;
    },


    _autoRefreshSelected: false,

    get_autoRefreshSelected: function FullSize_FullSizeHelper$get_autoRefreshSelected() {
        return this._autoRefreshSelected;
    },
    set_autoRefreshSelected: function FullSize_FullSizeHelper$set_autoRefreshSelected(value) {
        this._autoRefreshSelected = value;
        return value;
    },

    get_fullSizeCurrentSlideNumber: function FullSize_FullSizeHelper$get_fullSizeCurrentSlideNumber() {
        return this._fullSizeCurrentSlideNumber;
    },
    set_fullSizeCurrentSlideNumber: function FullSize_FullSizeHelper$set_fullSizeCurrentSlideNumber(value) {
        this._fullSizeCurrentSlideNumber = value;
        return value;
    },

    _commandEvents: null,

    get_commandEvents: function FullSize_FullSizeHelper$get_commandEvents() {
        return this._commandEvents;
    },
    set_commandEvents: function FullSize_FullSizeHelper$set_commandEvents(value) {
        this._commandEvents = value;
        return value;
    },

    _statusChangeEvents: null,

    get_statusChangeEvents: function FullSize_FullSizeHelper$get_statusChangeEvents() {
        return this._statusChangeEvents;
    },
    set_statusChangeEvents: function FullSize_FullSizeHelper$set_statusChangeEvents(value) {
        this._statusChangeEvents = value;
        return value;
    },

    postCommandEvent: function FullSize_FullSizeHelper$postCommandEvent(eventId, sender, args) {
        var handler = this._commandEvents.getHandler(eventId);
        if (!handler) {
            return;
        }
        handler(sender, args);
    },

    postStatusChangedEvent: function FullSize_FullSizeHelper$postStatusChangedEvent(eventId, sender, args) {
        var handler = this._statusChangeEvents.getHandler(eventId);
        if (!handler) {
            return;
        }
        handler(sender, args);
    }
}

FullSize.FullSizeSlidePanel = function FullSizeSlideArea(container, containingWindow, id) {
    this.ID = id;
    this.Container = container;
    this.ContainingWindow = containingWindow;

    this.FullSizeHelper = new FullSize.FullSizeHelper();

    this._image$1 = $('FullSizeImage');
    this._imageCache$1 = new SfImage.ImageCache(this.Container + '._imageCache$1');
}
FullSize.FullSizeSlidePanel.prototype = {
    _imageUpdater$1: null,
    _image$1: null,
    _imageCache$1: null,

    OnLoad: function FullSizeSlideArea$OnLoad() {
        var themeId = this.FullSizeHelper.get_layoutOptions().ThemeId;
        var imageFileType = '.png';
        this.LegacyThemeName = 'Mediasite for IE6';

        this.PlayerDetect = new SfKernel.PlayerDetect();

        if (this.PlayerDetect.IsInternetExplorer6() && !this.FullSizeHelper.get_manifest().IsStandAlone) {
            themeId = this.LegacyThemeName;
            // override theme for transparency compatibility on MSIE6.
        }

        if (themeId == this.LegacyThemeName) {
            imageFileType = '.gif';
        }
        else {
            imageFileType = '.png';
        }

        this.btnFullSizeNextSlideInstance = new FullSize.FullSizeNextSlideButtonArea("btnFullSizeNextSlideInstance", window, "btnFullSizeNextSlide");
        this.btnFullSizeNextSlideInstance.button = new SfUI.Button('btnFullSizeNextSlide');
        this.btnFullSizeNextSlideInstance.button.SetNormalImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnNextNormal' + imageFileType);
        this.btnFullSizeNextSlideInstance.button.SetOverImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnNextOver' + imageFileType);
        this.btnFullSizeNextSlideInstance.button.SetPressedImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnNextPressed' + imageFileType);
        this.btnFullSizeNextSlideInstance.button.SetDisabledImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnNextDisabled' + imageFileType);
        this.btnFullSizeNextSlideInstance.OnLoad();

        this.btnFullSizePreviousSlideInstance = new FullSize.FullSizePreviousSlideButtonArea("btnFullSizePreviousSlideInstance", window, "btnFullSizePreviousSlide");
        this.btnFullSizePreviousSlideInstance.button = new SfUI.Button('btnFullSizePreviousSlide');
        this.btnFullSizePreviousSlideInstance.button.SetNormalImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnPrevNormal' + imageFileType);
        this.btnFullSizePreviousSlideInstance.button.SetOverImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnPrevOver' + imageFileType);
        this.btnFullSizePreviousSlideInstance.button.SetPressedImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnPrevPressed' + imageFileType);
        this.btnFullSizePreviousSlideInstance.button.SetDisabledImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/btnPrevDisabled' + imageFileType);
        this.btnFullSizePreviousSlideInstance.OnLoad();

        this.btnFullSizePlayFromSlideInstance = new FullSize.FullSizePlayFromSlideButtonArea("btnFullSizePlayFromSlideInstance", window, "btnFullSizePlayFromSlide");
        this.btnFullSizePlayFromSlideInstance.button = new SfUI.Button('btnFullSizePlayFromSlide');
        this.btnFullSizePlayFromSlideInstance.button.SetNormalImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/playFromSlide' + imageFileType);
        this.btnFullSizePlayFromSlideInstance.button.SetOverImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/playFromSlideOver' + imageFileType);
        this.btnFullSizePlayFromSlideInstance.button.SetPressedImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/playFromSlideOver' + imageFileType);
        this.btnFullSizePlayFromSlideInstance.button.SetDisabledImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/playFromSlideDisabled' + imageFileType);
        this.btnFullSizePlayFromSlideInstance.OnLoad();

        this.btnFullSizeRefreshInstance = new FullSize.FullSizeRefreshButtonArea("btnFullSizeRefreshInstance", window, "btnFullSizeRefresh");
        this.btnFullSizeRefreshInstance.button = new SfUI.Button('btnFullSizeRefresh');
        this.btnFullSizeRefreshInstance.button.SetNormalImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/refresh' + imageFileType);
        this.btnFullSizeRefreshInstance.button.SetOverImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/refreshOver' + imageFileType);
        this.btnFullSizeRefreshInstance.button.SetPressedImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/refreshOver' + imageFileType);
        this.btnFullSizeRefreshInstance.button.SetDisabledImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/refreshDisabled' + imageFileType);
        this.btnFullSizeRefreshInstance.OnLoad();

        this.btnFullSizeAutoRefreshInstance = new FullSize.FullSizeAutoRefreshButtonArea("btnFullSizeAutoRefreshInstance", window, "btnFullSizeAutoRefresh");
        this.btnFullSizeAutoRefreshInstance.button = new SfUI.Button('btnFullSizeAutoRefresh');
        this.btnFullSizeAutoRefreshInstance.button.SetNormalImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/auto_refresh' + imageFileType);
        this.btnFullSizeAutoRefreshInstance.button.SetOverImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/auto_refresh' + imageFileType);
        this.btnFullSizeAutoRefreshInstance.button.SetPressedImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/auto_refresh' + imageFileType);
        this.btnFullSizeAutoRefreshInstance.button.SetDisabledImage(0, '../../App_Themes/' + themeId + '/Images/FullSize/auto_refresh' + imageFileType);
        this.btnFullSizeAutoRefreshInstance.OnLoad();

        this.FullSizeSlideNumberAreaInstance = new FullSize.FullSizeSlideNumberArea("FullSizeSlideNumberAreaInstance", window, "FullSizeSlideNumberArea");
        this.FullSizeSlideNumberAreaInstance.OnLoad();

        this.FullSizeAutoRefreshCheckBoxInstance = new FullSize.FullSizeAutoRefreshCheckBoxArea("FullSizeAutoRefreshCheckBoxInstance", window, "FullSizeAutoRefreshCheckBox");
        this.FullSizeAutoRefreshCheckBoxInstance.OnLoad();

        this._initializeImageUpdater$1();
        this._initializeImage$1();
        this._addEventHandlers$1();

    },

    _initializeImageUpdater$1: function FullSizeSlideArea$_initializeImageUpdater$1() {
        this._imageUpdater$1 = new SfImage.ImageUpdater(this.Container + '._imageUpdater$1', this._image$1, 0, this._getTopOffset$1(), 475, 100);
    },

    _getTopOffset$1: function FullSizeSlideArea$_getTopOffset$1() {
        var elem = $(this.ID);
        if (!elem) {
            return 0;
        }
        return Number(elem.offsetTop);
    },

    _initializeImage$1: function FullSizeSlideArea$_initializeImage$1() {
        this._changeImage$1(this.FullSizeHelper.get_mainPlayer().CurrentSlideNumber);
    },

    _addEventHandlers$1: function FullSizeSlideArea$_addEventHandlers$1() {
        this.FullSizeHelper.get_commandEvents().addHandler(FullSize.FullSizeCommandEventId.PreviousSlide, Function.createDelegate(this, this._onPreviousSlide$1));
        this.FullSizeHelper.get_commandEvents().addHandler(FullSize.FullSizeCommandEventId.NextSlide, Function.createDelegate(this, this._onNextSlide$1));
        this.FullSizeHelper.get_commandEvents().addHandler(FullSize.FullSizeCommandEventId.Refresh, Function.createDelegate(this, this._onRefresh$1));
        this.FullSizeHelper.get_commandEvents().addHandler(FullSize.FullSizeCommandEventId.PlayFromSlide, Function.createDelegate(this, this._onPlayFromSlide$1));
    },

    _changeImage$1: function FullSizeSlideArea$_changeImage$1(slideNumber) {
        if (this.FullSizeHelper.get_manifest().IsStandAlone) {
            this._imageUpdater$1.ChangeImage('../../' + this.FullSizeHelper.get_mainPlayer().GetImageLocation(slideNumber, SfKernel.SlideType.FullSize));
        }
        else {
            this._imageUpdater$1.ChangeImage(this.FullSizeHelper.get_mainPlayer().GetImageLocation(slideNumber, SfKernel.SlideType.FullSize));
        }

        if ((this.FullSizeHelper.get_manifest().PlayStatus !== "Live") && (slideNumber < this.FullSizeHelper.get_manifest().Slides.length)) {
            var nextImageUrl = this.FullSizeHelper.get_mainPlayer().GetImageLocation(slideNumber + 1, SfKernel.SlideType.FullSize);
            this._imageCache$1.AddImage(nextImageUrl, true);
        }
        this.FullSizeHelper.set_fullSizeCurrentSlideNumber(slideNumber);
        this.FullSizeHelper.postStatusChangedEvent(FullSize.StatusChangeEventId.SlideChanged, this, null);
    },

    UpdateIfNeeded: function FullSizeSlideArea$UpdateIfNeeded(fullSizeImage, slideNumber) {
        if (!this.FullSizeHelper.get_autoRefreshSelected()) {
            return;
        }
        this._changeImage$1(slideNumber);
    },

    _onPreviousSlide$1: function FullSizeSlideArea$_onPreviousSlide$1(sender, args) {
        this._changeImage$1(this.FullSizeHelper.get_fullSizeCurrentSlideNumber() - 1);
    },

    _onNextSlide$1: function FullSizeSlideArea$_onNextSlide$1(sender, args) {
        this._changeImage$1(this.FullSizeHelper.get_fullSizeCurrentSlideNumber() + 1);
    },

    _onRefresh$1: function FullSizeSlideArea$_onRefresh$1(sender, args) {
        this._changeImage$1(this.FullSizeHelper.get_mainPlayer().CurrentSlideNumber);
    },

    _onPlayFromSlide$1: function FullSizeSlideArea$_onPlayFromSlide$1(sender, args) {
        this.FullSizeHelper.get_mainPlayer().EventManager.PostCommandEvent(SfKernel.CommandEventId.NavigateToSlide, this, { SlideNumber: this.FullSizeHelper.get_fullSizeCurrentSlideNumber() });
    }
}


FullSize.FullSizeSlideNumberArea = function FullSizeSlideNumberArea(container, containingWindow, id) {
    this.ID = id;
}
FullSize.FullSizeSlideNumberArea.prototype = {
    _element$1: null,

    OnLoad: function FullSizeSlideNumberArea$OnLoad() {
        this._element$1 = $(this.ID);
        SfKernel.Util.SetText(this._element$1, Localization.Common.Slide);
        this._initializeSlideNumber$1();
        this._addEventHandlers$1();
    },

    _initializeSlideNumber$1: function FullSizeSlideNumberArea$_initializeSlideNumber$1() {
        if (SlidePlayer.FullSizeHelper.get_mainPlayer().CurrentSlideNumber > 0) {
            this._setSlideNumber$1(SlidePlayer.FullSizeHelper.get_mainPlayer().CurrentSlideNumber);
        }
        else {
            SfKernel.Util.SetText(this._element$1, Localization.Common.Slide);
        }
    },

    _addEventHandlers$1: function FullSizeSlideNumberArea$_addEventHandlers$1() {
        SlidePlayer.FullSizeHelper.get_statusChangeEvents().addHandler(FullSize.StatusChangeEventId.SlideChanged, Function.createDelegate(this, this._onSlideChanged$1));
    },

    _onSlideChanged$1: function FullSizeSlideNumberArea$_onSlideChanged$1(sender, args) {
        this._setSlideNumber$1(SlidePlayer.FullSizeHelper.get_fullSizeCurrentSlideNumber());
    },

    _setSlideNumber$1: function FullSizeSlideNumberArea$_setSlideNumber$1(slideNumber) {
        SfKernel.Util.SetText(this._element$1, Localization.Common.Slide + ' ' + slideNumber + ' ' + Localization.Common.Of + ' ' + SlidePlayer.FullSizeHelper.get_manifest().Slides.length);
    }
}


FullSize.FullSizeAutoRefreshCheckBoxArea = function FullSizeAutoRefreshCheckBoxArea(container, containingWindow, id) {
    this.ID = id;
}
FullSize.FullSizeAutoRefreshCheckBoxArea.prototype = {
    _checkbox$1: null,

    get__checkboxIsChecked$1: function FullSizeAutoRefreshCheckBoxArea$get__checkboxIsChecked$1() {
        return this._checkbox$1.checked;
    },
    set__checkboxIsChecked$1: function FullSizeAutoRefreshCheckBoxArea$set__checkboxIsChecked$1(value) {
        this._checkbox$1.checked = value;
        new MediasitePlayerCookie().SetBoolValue('NoAutoRefreshFullSlides', !value);
        SlidePlayer.FullSizeHelper.set_autoRefreshSelected(value);
        return value;
    },

    OnLoad: function FullSizeAutoRefreshCheckBoxArea$OnLoad() {
        this._checkbox$1 = $(this.ID + 'Input');
        this._checkbox$1.observe('click', Function.createDelegate(this, this._onClick$1));
        this.set__checkboxIsChecked$1(!(new MediasitePlayerCookie().GetBoolValue('NoAutoRefreshFullSlides')));
        SlidePlayer.FullSizeHelper.get_commandEvents().addHandler(FullSize.FullSizeCommandEventId.CheckboxToggle, Function.createDelegate(this, this._onCheckboxToggle$1));
    },

    _onClick$1: function FullSizeAutoRefreshCheckBoxArea$_onClick$1(sender, args) {
        this.set__checkboxIsChecked$1(this.get__checkboxIsChecked$1());
    },

    _onCheckboxToggle$1: function FullSizeAutoRefreshCheckBoxArea$_onCheckboxToggle$1(sender, args) {
        this.set__checkboxIsChecked$1(!this.get__checkboxIsChecked$1());
    }

}

FullSize.FullSizeAutoRefreshButtonArea = function(container, containingWindow, id) {
    this.OnLoad = function() {
        this.button.Initialize();
        this.button.SetClickHandler(this.OnClick.bind(this));
        this.button.SetTooltip(Localization.FullSize.AutoRefresh);
    }

    this.OnClick = function() {
        SlidePlayer.FullSizeHelper.postCommandEvent(FullSize.FullSizeCommandEventId.CheckboxToggle, this, null);
    }
}

FullSize.FullSizeNextSlideButtonArea = function(container, containingWindow, id) {
    this.OnLoad = function() {
        this.button.Initialize();
        this.button.SetClickHandler(this.OnClick.bind(this));
        this.button.SetTooltip(Localization.Common.NextSlide);

        this.InitializeButtonState();
        this.AddEventHandlers();
    }

    this.AddEventHandlers = function() {
        SlidePlayer.FullSizeHelper._statusChangeEvents.addHandler(FullSize.StatusChangeEventId.SlideChanged, this.SlideChangedEventHandler.bind(this));
    }

    this.OnClick = function() {
        SlidePlayer.FullSizeHelper.postCommandEvent(FullSize.FullSizeCommandEventId.NextSlide, this, null);
    }

    this.SlideChangedEventHandler = function(sender, args) {
        this.HandleButtonState(SlidePlayer.FullSizeHelper._fullSizeCurrentSlideNumber);
    }

    this.InitializeButtonState = function() {
        this.HandleButtonState(SlidePlayer.FullSizeHelper.get_mainPlayer().CurrentSlideNumber);
    }

    this.HandleButtonState = function(currentSlideNumber) {
        var status = SlidePlayer.FullSizeHelper.get_manifest().PlayStatus;
        if (status != SfKernel.PresentationPlayStatus.OnDemand && status != SfKernel.PresentationPlayStatus.Live && status != SfKernel.PresentationPlayStatus.LivePaused) {
            this.button.Enable(false);
            return;
        }

        if (currentSlideNumber < SlidePlayer.FullSizeHelper.get_manifest().Slides.length) {
            this.button.Enable(true);
        }
        else {
            this.button.Enable(false);
        }
    }
}

FullSize.FullSizePlayFromSlideButtonArea = function(container, containingWindow, id) {
    this.OnLoad = function() {
        this.button.Initialize();
        this.button.SetTooltip(Localization.FullSize.PlayFromSlide);

        if (SlidePlayer.FullSizeHelper.get_manifest().PlayStatus == SfKernel.PresentationPlayStatus.OnDemand) {
            this.button.Enable(true);
            this.button.SetClickHandler(this.OnClick.bind(this));
        }
        else {
            this.button.Enable(false);
        }

    }

    this.OnClick = function() {
        SlidePlayer.FullSizeHelper.postCommandEvent(FullSize.FullSizeCommandEventId.PlayFromSlide, this, null);
    }
}

FullSize.FullSizePreviousSlideButtonArea = function(container, containingWindow, id) {
    this.OnLoad = function() {
        this.button.Initialize();
        this.button.SetClickHandler(this.OnClick.bind(this));
        this.button.SetTooltip(Localization.Common.PreviousSlide);

        this.InitializeButtonState();
        this.AddEventHandlers();
    }

    this.AddEventHandlers = function() {
        SlidePlayer.FullSizeHelper._statusChangeEvents.addHandler(FullSize.StatusChangeEventId.SlideChanged, this.SlideChangedEventHandler.bind(this));
    }

    this.OnClick = function() {
        SlidePlayer.FullSizeHelper.postCommandEvent(FullSize.FullSizeCommandEventId.PreviousSlide, this, null);
    }

    this.SlideChangedEventHandler = function(sender, args) {
        this.HandleButtonState(SlidePlayer.FullSizeHelper._fullSizeCurrentSlideNumber);
    }

    this.InitializeButtonState = function() {
        this.HandleButtonState(SlidePlayer.FullSizeHelper.get_mainPlayer().CurrentSlideNumber);
    }

    this.HandleButtonState = function(currentSlideNumber) {
        var status = SlidePlayer.FullSizeHelper.get_manifest().PlayStatus;
        if (status != SfKernel.PresentationPlayStatus.OnDemand && status != SfKernel.PresentationPlayStatus.Live && status != SfKernel.PresentationPlayStatus.LivePaused) {
            this.button.Enable(false);
            return;
        }

        if (currentSlideNumber > 1) {
            this.button.Enable(true);
        }
        else {
            this.button.Enable(false);
        }
    }
}

FullSize.FullSizeRefreshButtonArea = function(container, containingWindow, id) {
    this.OnLoad = function() {
        this.button.Initialize();
        this.button.SetClickHandler(this.OnClick.bind(this));
        this.button.SetTooltip(Localization.FullSize.RefreshNow);
    }

    this.OnClick = function() {
        SlidePlayer.FullSizeHelper.postCommandEvent(FullSize.FullSizeCommandEventId.Refresh, this, null);
    }
}

var SlidePlayer = null;

var cssHref = null;
var isStandAlone = new FullSize.FullSizeHelper().get_manifest().IsStandAlone; 

this.PlayerDetect = new SfKernel.PlayerDetect();
this.LegacyThemeName = 'Mediasite for IE6';
var themeId;

if (this.PlayerDetect.IsInternetExplorer6() && !isStandAlone) {
    themeId = this.LegacyThemeName;
    // override theme for transparency compatibility on MSIE6.
}
else {
    themeId = new FullSize.FullSizeHelper().get_layoutOptions().ThemeId;
}

if (isStandAlone) {
    cssHref = GlobalOptions.AppRoot + '/../../App_Themes/' + themeId + '/Images.css';
}
else {
    cssHref = GlobalOptions.AppRoot + '/App_Themes/' + themeId + '/Images.css';
}

document.writeln("<link id='imageStylesheet' rel='stylesheet' type='text/css' href='" + cssHref + "'//>");


function onFullSizePageLoad() {
    SlidePlayer = new FullSize.FullSizeSlidePanel("SlidePlayer", window, "FullSizeSlideArea");
    SlidePlayer.OnLoad();
}

