Type.registerNamespace('Thumbnails');

////////////////////////////////////////////////////////////////////////////////
// Thumbnails.IRadioButtonGroup

Thumbnails.IRadioButtonGroup = function() { };
Thumbnails.IRadioButtonGroup.prototype = {
    selectButton : null
}
Thumbnails.IRadioButtonGroup.registerInterface('Thumbnails.IRadioButtonGroup');


////////////////////////////////////////////////////////////////////////////////
// Thumbnails.RadioImageInfo

Thumbnails.$create_RadioImageInfo = function Thumbnails_RadioImageInfo(overImage, normalImage, checkedImage) {
    var $o = { };
    $o.overImage = overImage;
    $o.normalImage = normalImage;
    $o.checkedImage = checkedImage;
    return $o;
}


////////////////////////////////////////////////////////////////////////////////
// Thumbnails.SlidesPerPageRadioButtonGroup

Thumbnails.SlidesPerPageRadioButtonGroup = function Thumbnails_SlidesPerPageRadioButtonGroup(parentArea) {
    this._buttons = new Array(5);
    this._slidesPerPageIndexMapping = [ 5, 10, 15, 20, 25 ];
    this._parentArea = parentArea;
    this._initialize();
}
Thumbnails.SlidesPerPageRadioButtonGroup.prototype = {
    _parentArea: null,
    
    _initialize: function Thumbnails_SlidesPerPageRadioButtonGroup$_initialize() {
        var initialNumSlidesPerPage = this._getInitialNumSlidesPerPage();
        for (var i = 0; i < this._buttons.length; ++i) {
            this._buttons[i] = new Thumbnails.RadioButton(this, Dollar('slidesPerPage' + i), Thumbnails.$create_RadioImageInfo(LayoutOptions.ThemeImageBase + '/SlideSorter/radioOver.gif', LayoutOptions.ThemeImageBase + '/SlideSorter/radioNormal.gif', LayoutOptions.ThemeImageBase + '/SlideSorter/radioChecked.gif'), null);
            if (initialNumSlidesPerPage === this._slidesPerPageIndexMapping[i]) {
                this._buttons[i].set_isChecked(true);
            }
            else {
                this._buttons[i].set_isChecked(false);
            }
        }
    },
    
    selectButton: function Thumbnails_SlidesPerPageRadioButtonGroup$selectButton(button) {
        for (var i = 0; i < this._buttons.length; ++i) {
            if (this._buttons[i] === button) {
                this._buttons[i].set_isChecked(true);
                this._parentArea.updateSlidesPerPage(this._slidesPerPageIndexMapping[i]);
            }
            else {
                this._buttons[i].set_isChecked(false);
            }
        }
    },
    
    _getInitialNumSlidesPerPage: function Thumbnails_SlidesPerPageRadioButtonGroup$_getInitialNumSlidesPerPage() {
        return new MediasitePlayerCookie().GetNumberValue('NumSlidesPerPage',5);
    }
}


////////////////////////////////////////////////////////////////////////////////
// Thumbnails.RadioButton

Thumbnails.RadioButton = function Thumbnails_RadioButton(group, element, imageInfo, tooltip) {
    this._group = group;
    this._element = element;
    this._imageInfo = imageInfo;
    this._tooltip = tooltip;
    this._element.observe('mouseover', Function.createDelegate(this, this._onMouseOver));
    this._element.observe('mouseout', Function.createDelegate(this, this._onMouseOut));
    this._element.observe('click', Function.createDelegate(this, this._onClick));
    if (this._tooltip) {
        SfDOM.SetToolTip(this._element, this._tooltip);
    }
}
Thumbnails.RadioButton.prototype = {
    _group: null,
    _element: null,
    _isChecked: false,
    _imageInfo: null,
    _tooltip: null,
    
    get_tooltip: function Thumbnails_RadioButton$get_tooltip() {
        return this._tooltip;
    },
    set_tooltip: function Thumbnails_RadioButton$set_tooltip(value) {
        this._tooltip = value;
        return value;
    },
    
    get_isChecked: function Thumbnails_RadioButton$get_isChecked() {
        return this._isChecked;
    },
    set_isChecked: function Thumbnails_RadioButton$set_isChecked(value) {
        this._isChecked = value;
        this._updateImage();
        return value;
    },
    
    _onClick: function Thumbnails_RadioButton$_onClick(sender, args) {
        this._group.selectButton(this);
    },
    
    _onMouseOver: function Thumbnails_RadioButton$_onMouseOver(sender, args) {
        if (this._isChecked) {
            return;
        }
        Util.SetCursor(this._element, CursorType.Hand);
        this._element.setAttribute('src', this._imageInfo.overImage);
    },
    
    _onMouseOut: function Thumbnails_RadioButton$_onMouseOut(sender, args) {
        this._updateImage();
        Util.SetCursor(this._element, CursorType.Default);
    },
    
    _updateImage: function Thumbnails_RadioButton$_updateImage() {
        if (this._isChecked) {
            this._element.setAttribute('src', this._imageInfo.checkedImage);
        }
        else {
            this._element.setAttribute('src', this._imageInfo.normalImage);
        }
    }
}


////////////////////////////////////////////////////////////////////////////////
// Thumbnails.PropertiesPopup

Thumbnails.PropertiesPopup = function Thumbnails_PropertiesPopup(parentArea) {
    this._parentArea = parentArea;
    this._initialize();
}
Thumbnails.PropertiesPopup.prototype = {
    _parentArea: null,
    _element: null,
    _closeButton: null,
    _slider: null,
    _isShowing: false,
    _enableSlideGroupsCheckbox: null,
    _propertiesButton: null,
    _slidesPerPageGroup: null,
    
    get_propertiesButton: function Thumbnails_PropertiesPopup$get_propertiesButton() {
        return this._propertiesButton;
    },
    set_propertiesButton: function Thumbnails_PropertiesPopup$set_propertiesButton(value) {
        this._propertiesButton = value;
        return value;
    },
    
    _initialize: function Thumbnails_PropertiesPopup$_initialize() {
        this._element = Dollar('thumbNailProperties');
        this._element.hide();
        this._closeButton = Dollar('thumbNailPropertiesCloseButton');
        this._addEvents();
        this._slider = new Thumbnails.SizingSlider(this._parentArea);
        this._slidesPerPageGroup = new Thumbnails.SlidesPerPageRadioButtonGroup(this._parentArea);
    },
    
    _getHeight: function Thumbnails_PropertiesPopup$_getHeight() {
        var height = this._element.getStyle('height');
        if (Util.IsNullOrUndefined(height)) {
            return '180';
        }
        return window.parseInt(height);
    },
    
    _addEvents: function Thumbnails_PropertiesPopup$_addEvents() {
        this._addSlideGroupEvents();
        this._addCloseButtonEvents();
    },
    
    _addSlideGroupEvents: function Thumbnails_PropertiesPopup$_addSlideGroupEvents() {
        var imageInfo = { NormalImage: LayoutOptions.ThemeImageBase + '/SlideSorter/checkBoxNormal.gif', OverImage: LayoutOptions.ThemeImageBase + '/SlideSorter/checkBoxOver.gif', CheckedImage: LayoutOptions.ThemeImageBase + '/SlideSorter/checkBoxChecked.gif', CheckedOverImage: LayoutOptions.ThemeImageBase + '/SlideSorter/checkBoxCheckedOver.gif', DisabledImage: LayoutOptions.ThemeImageBase + '/SlideSorter/checkBoxDisabled.gif' };
        this._enableSlideGroupsCheckbox = new SfUI.Checkbox(Dollar('enableSlideGroups'), imageInfo, true);
        this._enableSlideGroupsCheckbox.SetChecked(true);
        this._enableSlideGroupsCheckbox.SetOnClickMethod(Function.createDelegate(this, function(sender, args) {
            this._enableSlideGroupsCheckbox.Toggle();
            this._parentArea.setSlideGroupsIsEnabled(this._enableSlideGroupsCheckbox.GetChecked());
        }));
    },
    
    _addCloseButtonEvents: function Thumbnails_PropertiesPopup$_addCloseButtonEvents() {
        this._closeButton.observe('mouseover', Function.createDelegate(this, function(sender, args) {
            this._closeButton.className = 'thumbNailPropertiesCloseButtonOver';
        }));
        this._closeButton.observe('mouseout', Function.createDelegate(this, function(sender, args) {
            this._closeButton.className = 'thumbNailPropertiesCloseButtonNormal';
        }));
        this._closeButton.observe('click', Function.createDelegate(this, function(sender, args) {
            this._propertiesButton.HidePopup();
        }));
    },
    
    Show: function Thumbnails_PropertiesPopup$Show() {
        this._element.setStyle({ display: '' });
        this._slider.checkPositionInitialized();
        this._isShowing = true;
    },
    
    Hide: function Thumbnails_PropertiesPopup$Hide() {
        this._element.setStyle({ display: 'none' });
        this._isShowing = false;
    }
}


////////////////////////////////////////////////////////////////////////////////
// Thumbnails.PropertiesButton

Thumbnails.PropertiesButton = function Thumbnails_PropertiesButton(parentArea, popup) {
    this._parentArea = parentArea;
    this._popup = popup;
    this._initialize();
}
Thumbnails.PropertiesButton.prototype = {
    _parentArea: null,
    _popup: null,
    _element: null,
    _isChecked: false,
    
    HidePopup: function Thumbnails_PropertiesButton$HidePopup() {
        this._popup.Hide();
        this._isChecked = false;
        this._handleButtonImage();
    },
    
    Hide: function Thumbnails_PropertiesButton$Hide() {
        if (this._isChecked) {
            this.HidePopup();
        }
        this._element.hide();
    },
    
    Show: function Thumbnails_PropertiesButton$Show() {
        this._element.show();
    },
    
    _initialize: function Thumbnails_PropertiesButton$_initialize() {
        this._element = Dollar('thumbNailPropertiesButton');
        SfDOM.SetToolTip(this._element, Localization.ThumbnailsResource.Options);
        this._addEvents();
    },
    
    _addEvents: function Thumbnails_PropertiesButton$_addEvents() {
        this._element.observe('mouseover', Function.createDelegate(this, this._onMouseOver));
        this._element.observe('mouseout', Function.createDelegate(this, this._onMouseOut));
        this._element.observe('click', Function.createDelegate(this, this._onClick));
    },
    
    _onMouseOver: function Thumbnails_PropertiesButton$_onMouseOver(sender, args) {
        if (this._isChecked) {
            this._element.className = 'thumbNailPropertiesButtonCheckedOver';
        }
        else {
            this._element.className = 'thumbNailPropertiesButtonNormalOver';
        }
    },
    
    _onMouseOut: function Thumbnails_PropertiesButton$_onMouseOut(sender, args) {
        this._handleButtonImage();
    },
    
    _onClick: function Thumbnails_PropertiesButton$_onClick(sender, args) {
        if (!this._isChecked) {
            this._showPopup();
        }
    },
    
    _handleButtonImage: function Thumbnails_PropertiesButton$_handleButtonImage() {
        if (this._isChecked) {
            this._element.className = 'thumbNailPropertiesButtonChecked';
        }
        else {
            this._element.className = 'thumbNailPropertiesButtonNormal';
        }
    },
    
    _showPopup: function Thumbnails_PropertiesButton$_showPopup() {
        this._popup.Show();
        this._isChecked = true;
        this._handleButtonImage();
    }
}


Thumbnails.SlidesPerPageRadioButtonGroup.registerClass('Thumbnails.SlidesPerPageRadioButtonGroup', null, Thumbnails.IRadioButtonGroup);
Thumbnails.RadioButton.registerClass('Thumbnails.RadioButton');
Thumbnails.PropertiesPopup.registerClass('Thumbnails.PropertiesPopup');
Thumbnails.PropertiesButton.registerClass('Thumbnails.PropertiesButton');

// ---- Do not remove this footer ----
// Generated using Script# v0.4.2.0 (http://projects.nikhilk.net)
// -----------------------------------
